body.dvpublic {
    padding-top: inherit;
    margin-bottom: auto;

    // 2021 CI
    font-family: "Work Sans", sans-serif;

    h2, h3, h6 {
        // Work Sans Medium for titles
        font-weight: 500;
        text-rendering: optimizeLegibility;
        letter-spacing: -1px;
    }
    h2 {
        border-bottom: 1px solid #191919;
        font-size: 50px;
        line-height: 110%;
        margin-bottom: 20px;
        margin-top: 40px;
    }
    .pager li>a {
        color: inherit;
        background-color: inherit;
        border: 0;
        border-radius: 0;
        text-transform: uppercase;

        &:hover {
            background-color: transparent;
            color: #53a9d7;
        }
    }
    .dvqualif-badge {
        .dvstate-round {
            position: absolute;
            top: 38%;
            left: 15px;

            border-radius: 50%;
            width: 26px;
            font-size: 13px;
            padding: 0;
            color: white;
            * {
                text-align: center;
                line-height: 26px;
                display: block;
            }
        }
        .card-content {
            margin-left: 40px;
        }

        .date_big {
            font-size: 50px;
        }
    }
}
