.coordinator-home-video {
    // DEFIVELO-227
    position: relative;
    padding-top: 46%;
    margin-left: 10%;
    margin-right: 10%;

    iframe {
      position: absolute;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
    }
}
