body.dv-invoice {
  .invoice-address-from {
    float: left;
  }
  .invoice-address-to {
    float: right;
  }
  .invoice-date {
    clear: both;
    float: right;
    margin-top: 2em;
    margin-bottom: 0.5em;
  }
  .invoice-title {
    clear: both;
  }
  .invoice-status {
    float: left;
    border: 1px dotted $dv-red;
    padding: 1em;
    margin-left: 1em;
  }

  .invoice-header-text {
    padding-bottom: 1em;
    border-bottom: 1px solid #4fa2ce;
    margin-bottom: -1em;
    text-align: justify;
  }

  .invoice-table {
    margin: 1em auto !important;
    & > tbody,
    & > tfoot,
    & > thead {
      & > tr {
        & > td,
        & > th {
          border-color: $dv-blue;
          border-right-width: 1px;
          border-right-style: solid;
          padding: 4px;
        }
      }
    }
    .invoice-total {
      border: 2px solid $dv-red;
    }
  }

  .invoice-bank-details {
    float: left;
    margin-top: 2em;
    margin-right: 3em;
  }
  .invoice-footer-closing {
    clear: both;
    float: right;
    text-align: right;
  }
}

#watermark-container::after {
  content: attr(data-label);
  position: absolute;
  left: 50%;
  top: 40%;
  transform: translate(-50%,60%) rotate(-30deg);
  font-size: clamp(3rem, 12vw, 10rem);
  font-weight: 700;
  letter-spacing: .5rem;
  color: rgba(192,0,0,0.3) !important;
  white-space: nowrap;
  pointer-events: none;
  user-select: none;
  z-index: -1;
}
@media print {
  #watermark-container .table td, .table th {
    background-color: transparent !important;
  }
}
