{% load i18n %}
{% if page_obj %}
    <nav class="hidden-print">
        <ul class="pager">
        {% if page_obj.has_previous %}
            <li class="previous btn-xs">
                <a href="{% url listurl %}?page={{ page_obj.previous_page_number }}&{{ filter_querystring }}">
                    <span aria-hidden="true">&larr;</span> {% blocktrans with page_obj.previous_page_number as number %}Page {{number}}{% endblocktrans %}
                </a>
            </li>
        {% endif %}
            <li class="btn-xs">
                <span>
                    {{ page_obj.start_index }} - {{ page_obj.end_index }}/{{ page_obj.paginator.count }}
                </span>
            </li>
        {% if page_obj.has_next %}
            <li class="next btn-xs">
                <a href="{% url listurl %}?page={{ page_obj.next_page_number }}&{{ filter_querystring }}">
                    {% blocktrans with page_obj.next_page_number as number %}Page {{number}}{% endblocktrans %} <span aria-hidden="true">&rarr;</span>
                </a>
            </li>
        {% endif %}
        </ul>
    </nav>
{% endif %}
