# Generated by Django 1.11.20 on 2019-02-25 15:31
from __future__ import unicode_literals

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0051_auto_20181019_1411"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalhelperseasonworkwish",
            name="helper",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to=settings.AUTH_USER_MODEL,
                verbose_name="Moniteur",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhelperseasonworkwish",
            name="season",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="challenge.Season",
                verbose_name="Saison",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhelpersessionavailability",
            name="helper",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to=settings.AUTH_USER_MODEL,
                verbose_name="Moniteur",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhelpersessionavailability",
            name="session",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="challenge.Session",
                verbose_name="Session",
            ),
        ),
        migrations.AlterField(
            model_name="historicalqualification",
            name="activity_A",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="challenge.QualificationActivity",
                verbose_name="Agilité",
            ),
        ),
        migrations.AlterField(
            model_name="historicalqualification",
            name="activity_B",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="challenge.QualificationActivity",
                verbose_name="Mécanique",
            ),
        ),
        migrations.AlterField(
            model_name="historicalqualification",
            name="activity_C",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="challenge.QualificationActivity",
                verbose_name="Rencontre",
            ),
        ),
        migrations.AlterField(
            model_name="historicalqualification",
            name="actor",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to=settings.AUTH_USER_MODEL,
                verbose_name="Intervenant",
            ),
        ),
        migrations.AlterField(
            model_name="historicalqualification",
            name="leader",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to=settings.AUTH_USER_MODEL,
                verbose_name="Moniteur 2",
            ),
        ),
        migrations.AlterField(
            model_name="historicalseason",
            name="leader",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to=settings.AUTH_USER_MODEL,
                verbose_name="Chargé de projet",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsession",
            name="address_ptr",
            field=models.ForeignKey(
                auto_created=True,
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                parent_link=True,
                related_name="+",
                to="common.Address",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsession",
            name="orga",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="orga.Organization",
                verbose_name="Établissement",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsession",
            name="superleader",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to=settings.AUTH_USER_MODEL,
                verbose_name="Moniteur + / Photographe",
            ),
        ),
    ]
