{% extends "base.html" %}
{% load i18n %}
{% load bootstrap3 %}
{% load dv_filters %}

{% block head_title %}{% blocktrans with name=userprofile.get_full_name %}Envoyer les données de connexion à {{name}} ?{% endblocktrans %}{% endblock %}
{% block content %}
    <h2>{% if initial_send %}
        {% blocktrans with name=userprofile.get_full_name %}Envoyer les données de connexion à {{name}} ?{% endblocktrans %}
        {% else %}
        {% blocktrans with name=userprofile.get_full_name %}Réinitialiser les données de connexion pour {{name}} ?{% endblocktrans %}
        {% endif %}
    </h2>
    {% if not initial_send %}
        <div class="alert alert-danger">
        {% blocktrans with name=userprofile.get_full_name %}Cette action va <b>réinitialiser</b> le mot de passe de {{name}} !{% endblocktrans %}
        </div>
    {% endif %}
    <blockquote><pre style="white-space: pre-wrap;">{% include "auth/email_user_send_credentials.txt" with userprofile=userprofile fromuser=request.user current_site=current_site login_uri=login_uri password='******' %}</pre>
    </blockquote>
    <form method="POST" action="" class="form-horizontal">
        {% csrf_token %}
        {% bootstrap_form form layout='horizontal' size='small' %}
        {% buttons %}
            <button type="submit" class="btn btn-primary pull-right">{% trans 'Envoyer' %}</button>
            <a class="btn btn-default" href="{% url 'user-list' %}">{% trans "Annuler" %}</a>
        {% endbuttons %}
    </form>
{% endblock %}