# Generated by Django 4.2.6 on 2025-11-13 13:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('challenge', '0086_inclusive_language'),
        ('user', '0075_phone_length_fix'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userprofile',
            name='actor_for',
            field=models.ManyToManyField(blank=True, limit_choices_to={'category': 'C'}, related_name='actor_for', to='challenge.qualificationactivity', verbose_name='Intervenant·e'),
        ),
        migrations.AlterField(
            model_name='userprofile',
            name='formation',
            field=models.CharField(blank=True, choices=[('', '----------'), ('M1', 'Moniteur·trice 1'), ('M2', 'Moniteur·trice 2')], max_length=2, verbose_name='Formation'),
        ),
        migrations.AlterField(
            model_name='userprofile',
            name='status',
            field=models.PositiveSmallIntegerField(choices=[(0, '---------'), (10, 'Actif·ve'), (20, 'Réserve'), (30, 'Inactif·ve'), (40, 'Archivé·e'), (99, 'Supprimé·e')], default=10, verbose_name='Statut'),
        ),
    ]
