# Generated by Django 1.11.4 on 2017-08-31 12:37
from __future__ import unicode_literals

from django.contrib.auth import get_user_model
from django.db import migrations
from rolepermissions.checkers import has_role
from rolepermissions.roles import assign_role, clear_roles


def add_user_set_role_to_power_user(apps, schema_editor):
    # We can't import the Person model directly as it may be a newer
    # version than this migration expects. We use the historical version.
    User = get_user_model()
    for user in User.objects.all():
        if has_role(user, "power_user"):
            clear_roles(user)
            assign_role(user, "power_user")

        if has_role(user, "state_manager"):
            clear_roles(user)
            assign_role(user, "state_manager")


def remove_user_set_role_from_power_user(apps, schema_editor):
    # We can't import the Person model directly as it may be a newer
    # version than this migration expects. We use the historical version.
    pass


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0059_userprofile_phone"),
    ]

    operations = [
        migrations.RunPython(
            add_user_set_role_to_power_user, remove_user_set_role_from_power_user
        ),
    ]
