# Generated by Django 1.11.4 on 2017-08-18 09:45
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0030_auto_20170817_1642"),
    ]

    operations = [
        migrations.AlterField(
            model_name="userprofile",
            name="status",
            field=models.PositiveSmallIntegerField(
                choices=[
                    (0, "---------"),
                    (10, "Actif"),
                    (20, "Réserve"),
                    (30, "Inactif"),
                    (40, "Archive"),
                    (99, "Supprimé"),
                ],
                default=0,
                verbose_name="Statut",
            ),
        ),
    ]
