{% extends "skel.html" %}
{% load bootstrap3 static compress i18n dv_filters %}
{% block body %}
{% include "print/header.html" %}

{% block bootstrap3_content %}
    <nav class="navbar navbar-inverse navbar-fixed-top">
      <div class="container">
        <div class="navbar-header">
          <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#navbar" aria-expanded="false" aria-controls="navbar">
            <span class="sr-only">{% trans "Dérouler la navigation" %}</span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </button>
          <a id="dv-navbar-logo" class="navbar-brand" href="{% url 'home' %}" title="{% trans "Défi Vélo" %}">
                <img src="{% static 'img/2021_Defi_Velo_Logo_FR_1ligne_blanc.svg' %}" alt="{% trans "Défi Vélo" %}">
            </a>
        </div>
        <div id="navbar" class="navbar-collapse collapse">
          {% include "header.html" %}
        </div>
      </div>
    </nav>
    <div class="{% block container-class %}container{% endblock %}" role="main">
    {% block container %}
      <span class="hidden-print">{% bootstrap_messages %}</span>
      {% block content %}{% endblock %}
    {% endblock %}
    </div> <!-- /container -->
{% endblock %}
<footer class="footer hidden-print">
    <div class="container">
    {% block footer %}
        <ul class="list-inline text-muted pull-right">
            <li><a href="https://github.com/defivelo/db/commit/{% vcs_commit %}">{% vcs_version as vcs_version %}{% blocktrans %}Version {{ vcs_version }}{% endblocktrans %}</a></li>
            <li><a href="{% url 'license' %}">{% trans "AGPLv3 License" %}</a></li>
            <li><span title="Copyright">©</span> {% now 'Y' as now_year %}{% trans "Défi Vélo" %} 2015{% if now_year|add:'0' > 2015 %}-{{ now_year|add:'0' }}{% endif %}</li>
        </ul>
        <ul class="list-inline text-muted">
            <li><a href="https://github.com/defivelo/db/"><span class="glyphicon glyphicon-wrench"></span> {% trans "Code source" %}</a></li>
            <li><a href="https://github.com/defivelo/db/issues"><span class="glyphicon glyphicon-tasks"></span> {% trans "Rapports de bugs" %}</a></li>
            <li><a href="https://translate.liip.ch/projects/defivelo/intranet/"><span class="glyphicon glyphicon-globe"></span> {% trans "Traduction" %}</a></li>
            <li><a href="https://oriented.net/"><span class="glyphicon glyphicon-hdd" title="{% trans "Hébergement" %}"></span> oriented.net</a></li>
        </ul>
    {% endblock %}
    </div>
</footer>
{% include "print/footer.html" %}
{% endblock %}
