{% extends "base.html" %}
{% load i18n %}
{% load bootstrap3 %}
{% block head_title %}{% if invoice %}{% blocktrans with ref=invoice.ref %}Édition de la facture {{ref}}{% endblocktrans %}{% else %}{% trans "Création de facture" %}{% endif %}{% endblock %}

{% block bootstrap3_extra_head %}
{{ form.media.css }}
{% endblock %}
{% block bootstrap3_extra_script %}
    {{ form.media.js }}
    {% include 'snippets/datetimepicker_js.html' %}
{% endblock %}

{% block content %}
    <h1>{% if invoice %}{% blocktrans with ref=invoice.ref %}Édition de la facture {{ref}}{% endblocktrans %}{% else %}{% trans "Création de facture" %}{% endif %}</h1>

    <form method="POST" class="form-horizontal">
        {% csrf_token %}
        {% bootstrap_form form layout='horizontal' size='small' %}
        {% buttons %}
            <button type="submit" class="btn btn-primary pull-right">{% trans "Enregistrer" %}</button>
        {% endbuttons %}
    </form>

{% endblock %}
