# Generated by Django 1.11.4 on 2017-08-14 13:52
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0033_auto_20170131_2000"),
    ]

    operations = [
        migrations.RenameField(
            model_name="session",
            old_name="organization",
            new_name="orga",
        ),
    ]
