# Generated by Django 2.2.16 on 2020-11-02 17:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0062_add_schwyz"),
    ]

    operations = [
        migrations.AlterField(
            model_name="userprofile",
            name="affiliation_canton",
            field=models.CharField(
                blank=True,
                choices=[
                    ("", "---------"),
                    ("AG", "Aargau"),
                    ("AR", "Appenzell Ausserrhoden"),
                    ("BS", "Basel-Stadt"),
                    ("BL", "Basel-Land"),
                    ("BE", "Berne"),
                    ("FR", "Fribourg"),
                    ("GE", "Geneva"),
                    ("GR", "Graubuenden"),
                    ("JU", "Jura"),
                    ("LU", "Lucerne"),
                    ("NE", "Neuchatel"),
                    ("SZ", "Schwyz"),
                    ("SO", "Solothurn"),
                    ("SG", "St. Gallen"),
                    ("VS", "Valais"),
                    ("VD", "Vaud"),
                    ("ZH", "Zurich"),
                    ("WS", "Haut-Valais"),
                ],
                max_length=5,
                verbose_name="Canton d’affiliation",
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="cresus_employee_number",
            field=models.CharField(
                blank=True, max_length=63, verbose_name="Numéro d’employé Crésus"
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="tax_jurisdiction",
            field=models.CharField(
                blank=True, max_length=511, verbose_name="Lieu d’imposition"
            ),
        ),
    ]
