{% extends "account/base.html" %}
{% load i18n %}
{% load bootstrap3 %}
{% load account %}

{% block head_title %}{% trans "Password Reset" %}{% endblock %}

{% block content %}
  <h1>{% trans "Password Reset" %}</h1>
  {% if user.is_authenticated %}
    {% include "account/snippets/already_logged_in.html" %}
  {% endif %}

  <p>{% blocktrans %}We have sent you an email. If you have not received it please check your spam folder. Otherwise contact us if you do not receive it in a few minutes.{% endblocktrans %}</p>
{% endblock %}
