# Generated by Django 2.2.9 on 2020-03-05 16:53

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0057_invoice_invoiceline"),
    ]

    operations = [
        migrations.AlterField(
            model_name="invoice",
            name="status",
            field=models.IntegerField(
                choices=[(0, "Brouillon"), (1, "Validée")],
                default=0,
                verbose_name="Statut",
            ),
        ),
    ]
