# Generated by Django 1.11.4 on 2017-08-21 15:02
from __future__ import unicode_literals

import django.db.models.manager
import django_countries.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0033_auto_20170818_1626"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="userprofile",
            managers=[
                ("objects_existing", django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name="userprofile",
            name="nationality",
            field=django_countries.fields.CountryField(
                default="CH", max_length=2, verbose_name="Nationalité"
            ),
        ),
        migrations.AddField(
            model_name="userprofile",
            name="work_permit",
            field=models.CharField(
                blank=True,
                max_length=255,
                verbose_name="Permis de travail (si pas suisse)",
            ),
        ),
    ]
