{% extends "base.html" %}
{% load i18n %}
{% load bootstrap3 %}
{% load dv_filters %}
{% block head_title %}{% trans "Disponibilités" %} {{ session.pk }}{% endblock %}

{% block content %}
    {% include 'challenge/session_header.html' with session=session only %}

    <h2>{% trans "Choisis pour la session" %}</h2>
    <table class="table">
    {% for avail in session.chosen_staff %}
        {% ifchanged avail.chosen_as %}
        <tr>
            <th>{{ avail.chosen_as_icon }}</th>
            <th colspan="2">{{ avail.chosen_as_verb }}</th>
        </tr>
        {% endifchanged %}
        <tr>
            <td>{{ avail.availability_icon }}</td>
            <td>{{ avail.helper.profile.formation_icon }}{{ avail.helper.profile.actor_icon }}</td>
            <td>{{ avail.helper.get_full_name }}</td>
        </tr>
    {% endfor %}
    </table>

    <div class="hidden-print">
        <a class="btn btn-default" href="{% url 'session-detail' seasonpk=season.pk pk=session.pk %}">{% trans "Retour à la session" %}</a>
    </div>
{% endblock %}
