# Generated by Django 4.2.6 on 2025-12-01 12:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('salary', '0018_add_states_ow_nw'),
    ]

    operations = [
        migrations.AlterField(
            model_name='timesheet',
            name='leader_count',
            field=models.IntegerField(default=0, verbose_name='Participation(s) comme moniteur·trice 2'),
        ),
    ]
