# Generated by Django 1.11.4 on 2017-09-05 13:16
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0046_add_helpersessionavailability_chosen_as"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="helpersessionavailability",
            name="chosen",
        ),
    ]
