# Generated by Django 1.11.5 on 2017-09-07 10:59
from __future__ import unicode_literals

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("challenge", "0048_auto_20170907_1239"),
    ]

    operations = [
        migrations.CreateModel(
            name="HelperSeasonWorkWish",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_on", models.DateTimeField(auto_now_add=True)),
                (
                    "amount",
                    models.PositiveSmallIntegerField(
                        default=0, verbose_name="Quantit\xe9 d'engagements souhait\xe9s"
                    ),
                ),
                (
                    "helper",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="work_wishes",
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="Moniteur",
                    ),
                ),
                (
                    "season",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="work_wishes",
                        to="challenge.Season",
                        verbose_name="Saison",
                    ),
                ),
            ],
        ),
    ]
