{% load i18n %}
{% load static %}
<header id="print-header" class="visible-print-block row small">
    <div class="col-xs-4 text-left"><img src="{% static 'img/2021_Defi_Velo_Logo_FR_2lignes_couleur.svg' %}" alt="{% trans "Défi Vélo" %}" id="print-logo"/></div>
    <div class="col-xs-4 text-center">{% block head_title %}{% endblock %}</div>
    <div class="col-xs-4 text-right">&nbsp;</div>
</header>
