# Generated by Django 1.11.4 on 2017-08-29 07:59
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("orga", "0004_auto_20170817_1424"),
    ]

    operations = [
        migrations.AddField(
            model_name="organization",
            name="abbr",
            field=models.CharField(
                blank=True, max_length=16, verbose_name="Abbréviation"
            ),
        ),
        migrations.AddField(
            model_name="organization",
            name="status",
            field=models.PositiveSmallIntegerField(
                choices=[(0, "---------"), (10, "Actif"), (30, "Inactif")],
                default=10,
                verbose_name="Statut",
            ),
        ),
    ]
