# Generated by Django 1.11.4 on 2017-09-05 10:30
from __future__ import unicode_literals

from django.contrib.postgres.operations import UnaccentExtension
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("common", "0005_VS-OW_to_WS"),
    ]

    operations = [UnaccentExtension()]
