.footer {
    position: absolute;
    bottom: 0;
    width: 100%;
    background-color: #f5f5f5;
    
    .container .text-muted {
        margin: $global-footer-height/3 0;
        font-size: 0.7em;
    }
}
