{% extends "base.html" %}
{% load bootstrap3 dv_filters i18n %}
{% block head_title %}{% trans "Confirmer la pré-inscription" %}{% endblock %}

{% block bootstrap3_extra_script %}
  <script type="text/javascript">
    $("#id_is_terms_accepted").on("change", function() {
      $("#btn-confirm").prop("disabled", !this.checked);
    });
  </script>
{% endblock %}

{% block content %}
  <h1>{% trans "Confirmer la pré-inscription" %}</h1>

  {% include "orga/_organization_detail.html" %}

  <div class="panel panel-success">
    <div class="panel-heading">
      <h2 class="panel-title">{% trans 'Pré-inscription' %}</h2>
    </div>
    <table class="table">
      <tr>
        <th>{% trans 'Date' %}</th>
        <th>{% trans 'Moment de la journée' %}</th>
        <th>{% trans 'Nombre de classes' %}</th>
      </tr>
      {% for line in lines %}
        <tr>
          <td>{{ line.date|date:"DATE_FORMAT" }}</td>
          <td>{{ line.day_time }}</td>
          <td>{{ line.classes_amount }}</td>
        </tr>
      {% endfor %}
      <tr>
        <th colspan="2">{% trans 'Total de classes' %}</th>
        <th>{{ total_classes }}</th>
      </tr>
    </table>
  </div>

  <div class="panel panel-warning">
    <div class="panel-heading">
      <h2 class="panel-title">{% trans 'Conditions générales' %}</h2>
    </div>
    <div class="panel-body">
      {% blocktrans trimmed %}
<h3>Conditions générales DÉFI VÉLO</h3>

<p>En validant l’inscription de votre établissement à DÉFI VÉLO, vous vous engagez à :</p>
<ul>
<li>Fournir les informations nécessaires à la bonne organisation (dates, horaires, lieu, nombre de participant·es, nom et n° de téléphone de l’enseignant·e sur place et commandes des vélos et casques en prêt) au plus tard 3 semaines avant le premier jour de Qualifs.</li>
<li>Mettre à disposition un espace extérieur pour le déroulement des Qualifs et intérieur en cas de choix de la variante programme déluge en cas de mauvais temps.</li>
<li>Transmettre les informations aux participant·e·s</li>
<li>Assurer la présence d’un·e représentant·e de l’établissement durant chaque Qualif’ (3h). Cette personne n’est pas tenue de faire du vélo mais doit être informée sur son rôle</li>
<li>Assumer le rôle d’autorité vis-à-vis des participant·e·s</li>
<li>Effectuer d'avance le versement de la finance de participation de CHF 5./participant·e et, le cas échéant, CHF 16./vélo/jour (identique pour une demi-journée ou journée complète). Rabais en cas de journées consécutives : 2 jours = 5 %; 3 jours = 10 %; 4 jours = 20 %; 5 jours = 30 %). Dans certains cantons les frais d’inscription et/ou la location des vélos sont pris en charge par le canton.</li>
<li>En cas de programme Déluge, les frais de location vélos restent dus.</li>
<li>En cas d’annulation jusqu’à une semaine avant la première Qualif’, aucun frais n’est dû. A moins d’une semaine de la première Qualif’, 50 % des frais seront facturés. En cas d’annulation 3 jours, ou moins, avant la première Qualif’ 100 % des frais sont dus.</li>
<li>Rappeler aux participant·e·s la date de la Finale et les motiver à y participer.</li>
<li>Confirmer aux organisateurs de DÉFI VÉLO les inscriptions des équipes finalistes</li>
<li>Les éventuels dégâts constatés sur les vélos loués seront facturés. En cas de vol d’un vélo de location, DÉFI VÉLO se réserve le droit, après éclaircissement des faits, de facturer le coût du vélo à l’établissement</li>
</ul>
<p>De plus, DÉFI VÉLO s’engage à</p>
<ul>
<li>Être disponible pour répondre à toutes vos questions</li>
<li>Assurer la bonne organisation (commande des vélos et casques en prêt et communication)</li>
<li>Engager des moniteur·trice·s formé·e·s selon les exigences du Conseil Suisse de Sécurité Routière. Ces moniteurs sont au nombre de 3 par classe (de 15 à 2 participant·e·s), c’est-à-dire 1 par équipe de 5 à 8 participant·e·s</li>
<li>Assurer la sécurité et porter la responsabilité vis-à-vis des participant·e·s, c’est à dire s’assurer que toutes les mesures aient été prises et toutes les informations transmises pour que les participant·e·s puissent prendre part aux activités en sécurité, en particulier lors des sorties dans le trafic</li>
<li>Organiser la Finale</li>
</ul>
      {% endblocktrans %}
    </div>
  </div>

  <form method="POST" action="">
    <div>
      {% csrf_token %}
      {% bootstrap_field form.is_terms_accepted %}
    </div>

    {% buttons %}
      <button id="btn-confirm" class="btn btn-primary pull-right" type="submit" disabled>
        {% trans "Soumettre la pré-inscription" %}
      </button>
      <a class="btn btn-default" href="{% url "registration-create" %}">
        {% trans "Modifier" %}
      </a>
    {% endbuttons %}

  </form>

{% endblock %}
