# Generated by Django 2.2.12 on 2020-05-12 14:38

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0064_alter_invoiceline_ordering_again"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalsession",
            name="visible",
            field=models.BooleanField(
                default=False, verbose_name="Visible pour les moniteurs"
            ),
        ),
        migrations.AddField(
            model_name="session",
            name="visible",
            field=models.BooleanField(
                default=False, verbose_name="Visible pour les moniteurs"
            ),
        ),
    ]
