{% load i18n %}
{% load dv_filters %}
    <tr>
        <td rowspan="3" colspan="{{ preamble_columns|default:3 }}">&nbsp;</td>
        {% for session in sessions %}
            <th data-filter-orga="{{ session.orga.pk }}" class="text-center" style="vertical-align: top;">
                {% if session.orga.abbr %}{{ session.orga.abbr_verb }}{% else %}{{ session.orga.name }}{% endif %}
            </th>
        {% endfor %}</tr>
    <tr>{% for session in sessions %}
            <th data-filter-orga="{{ session.orga.pk }}"class="text-center">{{ session.day|date:"D" }} {{ session.day|date_ch_short }}</th>
        {% endfor %}</tr>
    <tr>{% for session in sessions %}
            <th style="font-weight: normal" data-filter-orga="{{ session.orga.pk }}" class="text-center">{{ session.begin|date:"H\hi" }}</th>
        {% endfor %}</tr>
