# Generated by Django 4.2.6 on 2025-09-16 06:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('challenge', '0082_add_states_ow_nw'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicalqualification',
            name='n_helpers',
            field=models.IntegerField(choices=[(1, '1'), (2, '2'), (3, '3')], default=3, verbose_name='Nombre de moniteurs'),
        ),
        migrations.AddField(
            model_name='qualification',
            name='n_helpers',
            field=models.IntegerField(choices=[(1, '1'), (2, '2'), (3, '3')], default=3, verbose_name='Nombre de moniteurs'),
        ),
    ]
