# Generated by Django 2.2.12 on 2020-05-20 07:05

import localflavor.generic.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0057_orga_detail_all_perm"),
    ]

    operations = [
        migrations.AlterField(
            model_name="userprofile",
            name="iban",
            field=localflavor.generic.models.IBANField(
                blank=True,
                include_countries=(
                    "AT",
                    "BE",
                    "BG",
                    "CH",
                    "CY",
                    "CZ",
                    "DE",
                    "DK",
                    "EE",
                    "ES",
                    "FI",
                    "FR",
                    "GB",
                    "GI",
                    "GR",
                    "HR",
                    "HU",
                    "IE",
                    "IS",
                    "IT",
                    "LI",
                    "LT",
                    "LU",
                    "LV",
                    "MC",
                    "MT",
                    "NL",
                    "NO",
                    "PL",
                    "PT",
                    "RO",
                    "SE",
                    "SI",
                    "SK",
                    "SM",
                ),
                max_length=34,
                use_nordea_extensions=False,
                verbose_name="Coordonnées bancaires (IBAN)",
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="social_security",
            field=models.CharField(blank=True, max_length=16, verbose_name="N° AVS"),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="tax_jurisdiction",
            field=models.CharField(
                blank=True, max_length=511, verbose_name="Lieu d'imposition"
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="work_permit",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Permis de travail"
            ),
        ),
    ]
