# Generated by Django 2.2.9 on 2020-04-08 12:41

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0062_data_invoiceline_historical_session"),
    ]

    operations = [
        migrations.AlterField(
            model_name="invoiceline",
            name="historical_session",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                to="challenge.HistoricalSession",
            ),
        ),
    ]
