# Generated by Django 2.2.9 on 2020-04-08 11:47

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0059_auto_20200305_1631"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="invoiceline",
            options={"ordering": ("session__day", "session__begin")},
        ),
    ]
