{% load static %}
<script type="text/javascript" src="{% static 'moment-with-locales.min.js' %}"></script>
<script type="text/javascript" src="{% static 'js/bootstrap-datetimepicker.min.js' %}"></script>
