# Generated by Django 1.11.4 on 2017-08-18 14:33
from __future__ import unicode_literals

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0035_auto_20170818_1626"),
    ]

    operations = [
        migrations.AlterField(
            model_name="session",
            name="superleader",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="sess_monplus",
                to=settings.AUTH_USER_MODEL,
                verbose_name="Moniteur + / Photographe",
            ),
        ),
    ]
