{% load dv_filters i18n %}
<nav class="hidden-print">
    <ul class="pager">
        <li class="previous">
            <a href="{% if previous_url %}{{ previous_url}}{% else %}{% url nav_url month=previous_month.month year=previous_month.year %}{% endif %}">
                <span aria-hidden="true">←</span> {{ previous_month|date:'F' }} {{ previous_month.year }}
            </a>
        </li>

        <li class="next">
            <a href="{% if next_url %}{{ next_url}}{% else %}{% url nav_url month=next_month.month year=next_month.year %}{% endif %}">
                {{ next_month|date:'F' }} {{ next_month.year }} <span aria-hidden="true">→</span>
            </a>
        </li>
    </ul>
</nav>
