# Generated by Django 4.2.6 on 2025-11-13 13:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('orga', '0008_auto_20200518_0322'),
    ]

    operations = [
        migrations.AlterField(
            model_name='organization',
            name='status',
            field=models.PositiveSmallIntegerField(choices=[(0, '---------'), (10, 'Actif·ve'), (30, 'Inactif·ve')], default=10, verbose_name='Statut'),
        ),
        migrations.AlterField(
            model_name='organization',
            name='status',
            field=models.PositiveSmallIntegerField(
                choices=[(0, '---------'), (10, 'Actif'), (30, 'Inactif')], default=10,
                verbose_name='Statut'),
        ),
    ]
