# Generated by Django 1.11.4 on 2017-08-24 10:12
from __future__ import unicode_literals

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0037_auto_20170824_1109"),
    ]

    operations = [
        migrations.AlterField(
            model_name="qualification",
            name="activity_A",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="qualifs_A",
                to="challenge.QualificationActivity",
                verbose_name="Agilité",
            ),
        ),
        migrations.AlterField(
            model_name="qualificationactivity",
            name="category",
            field=models.CharField(
                blank=True,
                choices=[("A", "Agilité"), ("B", "Mécanique"), ("C", "Rencontre")],
                max_length=1,
                verbose_name="Catégorie",
            ),
        ),
        migrations.AlterField(
            model_name="season",
            name="cantons",
            field=models.CharField(
                choices=[
                    ("AR", "Appenzell Ausserrhoden"),
                    ("BE", "Berne"),
                    ("BS", "Basel-Stadt"),
                    ("FR", "Fribourg"),
                    ("GE", "Geneva"),
                    ("VS-OW", "Haut-Valais"),
                    ("JU", "Jura"),
                    ("LU", "Lucerne"),
                    ("NE", "Neuchatel"),
                    ("SG", "St. Gallen"),
                    ("VS", "Valais"),
                    ("VD", "Vaud"),
                    ("ZH", "Zurich"),
                ],
                max_length=41,
                verbose_name="Cantons",
            ),
        ),
    ]
