{% load dv_filters i18n %}
<td data-filter-ignore class="text-left">
  {% if with_link %}
    <a title="{% trans "Éditer les disponibilités" %}" href="{% url 'season-availabilities-update' pk=season.pk helperpk=helper.pk %}">
  {% endif %}
        {% if helper.profile.status != 10 %}<em>{% endif %}
            {{ helper.get_full_name }}
        {% if helper.profile.status != 10 %}</em>{% endif %}
  {% if with_link %}
    </a>
    {% trans 'Retour au planning' as return_label %}
    <a href="{% url 'user-detail' pk=helper.pk %}?returnUrl={{ request.get_full_path|urlencode }}&returnLabel={{ return_label|urlencode }}" title="{% trans "Voir le profil" %}">
        <span class="glyphicon glyphicon-user"></span>
    </a>
  {% endif %}
</td>
<td data-filter-ignore class="no-vert-border">
    {% if helper.profile.status != 10 %}{{ helper.profile.status_icon }}{% endif %}
    {{ helper.profile.actor_icon }}
</td>
<td data-filter-ignore class="no-vert-border">
    {% if helper.profile.affiliation_canton in season.cantons %}<em class="small">{% endif %}
        {{ helper.profile.affiliation_canton|canton_abbr }}
    {% if helper.profile.affiliation_canton in season.cantons %}</em>{% endif %}
</td>
{% if availabilities %}
    {% with chosen_for=availabilities|chosen_staff_for_season:helper work_wish=availabilities|work_wish_for_season:helper %}
        <td data-filter-ignore data-chosenfor >{{ chosen_for }}</td>
        <td data-filter-ignore data-workwish="{{ work_wish }}"><span {% if not work_wish or chosen_for <= work_wish %}style="display:none"{% endif %} class="glyphicon glyphicon-alert" title="{{ chosen_for }}/{{ work_wish }}"></span>&nbsp;{{ work_wish }}</td>
    {% endwith %}
{% endif %}
