# Generated by Django 1.11.4 on 2017-08-31 10:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("orga", "0005_auto_20170829_0959"),
    ]

    operations = [
        migrations.AlterField(
            model_name="organization",
            name="abbr",
            field=models.CharField(
                blank=True, max_length=16, verbose_name="Abréviation"
            ),
        ),
    ]
